#!/usr/bin/python3
"""
Initialize FTDI EEPROM and assign serial number.

Warning: this script may give undefined results if more than one FTDI chip is
connected to USB ports at the same time!
"""


from pyftdi.eeprom import FtdiEeprom
from pyftdi.misc import hexdump

eeprom = FtdiEeprom()
eeprom.open('ftdi://ftdi:ft4232h/1')
print('Dumping current EEPROM config')
eeprom.dump_config()
print(hexdump(eeprom.data))
try:
    if eeprom.has_serial:
        print('This FTDI has SN already assigned, aborting!')
        exit(1)
except AttributeError:
    pass

print('\nInitializing config:')
eeprom.initialize()
print(hexdump(eeprom.data))
print('Writing EEPROM...')
if not eeprom.commit(dry_run=False):
    print('...done')
else:
    print('error, no changes written')
